@@ -160,6 +160,7 @@ enum {
     OPTION_SURFACE_BUFFER_SIZE,
     OPTION_COMMAND_BUFFER_SIZE,
     OPTION_SPICE_SMARTCARD_FILE,
+    OPTION_SPICE_VIDEO_CODECS,
 #endif
     OPTION_COUNT,
 };
@@ -235,6 +236,7 @@ struct _qxl_screen_t
     struct qxl_ring *		cursor_ring;
     struct qxl_ring *		release_ring;
 
+    Bool                        screen_resources_created;
     int                         device_primary;
     struct qxl_bo *             primary_bo;
     int				num_modes;
@@ -273,11 +275,9 @@ struct _qxl_screen_t
     xf86OutputPtr *             outputs;
 
 #ifndef XSPICE
-    void *			io_pages;
-    void *			io_pages_physical;
-
 #ifdef XSERVER_LIBPCIACCESS
     struct pci_device *		pci;
+    struct pci_io_handle *	io;
 #else
     pciVideoPtr			pci;
     PCITAG			pci_tag;
@@ -636,7 +636,7 @@ void ioport_write(qxl_screen_t *qxl, uint32_t io_port, uint32_t val);
 #else
 static inline void ioport_write(qxl_screen_t *qxl, int port, int val)
 {
-    outb(qxl->io_base + port, val);
+    pci_io_write8(qxl->io, port, val);
 }
 #endif
 
